@@ -1,6 +1,6 @@
 cat("\nTests for 'jmodelTM'")
 
-myEps <- .Machine$double.eps
+myEps <- if (capabilities("long.double")) .Machine$double.eps else 1e-9
 
 fitLME <- lme(sqrt(CD4) ~ drug + obstime + I(obstime ^ 2) + drug : obstime + drug : I(obstime ^2), random = ~ 1 | ID, data = aids)
 fitCOX <- coxph(Surv(start, stop, event) ~ drug, data = aids, x = TRUE)
@@ -17,4 +17,3 @@ test_that(" basic jmodelTM test with for aids data model = 2, rho = 1 ", {
   expect_equal( m_TM$coefficients$lgLik, -2522.503, tolerance = (10 ^ 13) * myEps, scale = 1)
   expect_equal( mean(m_TM$coefficients$lamb$bashaz), 0.005155245, tolerance = (10 ^ 7) * myEps, scale = 1)
 })
-
